@@ -1,5 +1,5 @@
 package PHP::Functions::Password;
-# $Id: Password.pm,v 1.4 2017/06/21 19:51:04 cmanley Exp $
+# $Id: Password.pm,v 1.5 2017/06/22 09:13:48 cmanley Exp $
 use strict;
 use warnings;
 use Carp qw(croak);
@@ -23,7 +23,7 @@ our %EXPORT_TAGS = (
 	'consts'	=> [ grep /^PASSWORD_/, @EXPORT_OK ],
 	'funcs'		=> [ grep /^password_/, @EXPORT_OK ],
 );
-our $VERSION = sprintf '%d.%02d', q{$Revision: 1.4 $} =~ m/ (\d+) \. (\d+) /xg;
+our $VERSION = sprintf '%d.%02d', q{$Revision: 1.5 $} =~ m/ (\d+) \. (\d+) /xg;
 
 use constant PASSWORD_BCRYPT => 1;
 use constant PASSWORD_DEFAULT => PASSWORD_BCRYPT;
@@ -141,7 +141,7 @@ with difference that the $algo argument is optional and defaults to PASSWORD_DEF
 sub password_hash {
 	my $proto = @_ && UNIVERSAL::isa($_[0],__PACKAGE__) ? shift : __PACKAGE__;
 	my $password = shift;
-	my $algo = shift // PASSWORD_DEFAULT;
+	my $algo = shift(@_) // PASSWORD_DEFAULT;
 	($algo == PASSWORD_BCRYPT) || croak("Unsupported algorithm $algo");
 	my %options = @_ && ref($_[0]) ? %{$_[0]} : @_;
 	my $salt = $options{'salt'} || $proto->_en_base64(Crypt::OpenSSL::Random::random_bytes(16));
@@ -162,7 +162,7 @@ The same as L<http://php.net/manual/en/function.password-needs-rehash.php>.
 sub password_needs_rehash {
 	my $proto = @_ && UNIVERSAL::isa($_[0],__PACKAGE__) ? shift : __PACKAGE__;
 	my $crypted = shift;
-	my $algo = shift // PASSWORD_DEFAULT;
+	my $algo = shift(@_) // PASSWORD_DEFAULT;
 	my %options = @_ && ref($_[0]) ? %{$_[0]} : @_;
 	my $cost = $options{'cost'} // COST_DEFAULT;
 	unless ($algo == PASSWORD_BCRYPT) {
